@@ -1,6 +1,6 @@
 # vim: tabstop=4 shiftwidth=4 softtabstop=4
 
-# Copyright 2011 OpenStack LLC.
+# Copyright 2011 OpenStack Foundation.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -21,8 +21,6 @@ Exceptions common to OpenStack projects
 
 import logging
 
-from heat.openstack.common.gettextutils import _
-
 _FATAL_EXCEPTION_FORMAT_ERRORS = False
 
 
@@ -98,7 +96,7 @@ def wrap_exception(f):
     def _wrap(*args, **kw):
         try:
             return f(*args, **kw)
-        except Exception, e:
+        except Exception as e:
             if not isinstance(e, Error):
                 #exc_type, exc_value, exc_traceback = sys.exc_info()
                 logging.exception(_('Uncaught exception'))
@@ -110,8 +108,7 @@ def wrap_exception(f):
 
 
 class OpenstackException(Exception):
-    """
-    Base Exception
+    """Base Exception class.
 
     To correctly use this class, inherit from it and define
     a 'message' property. That message will get printf'd
@@ -121,6 +118,7 @@ class OpenstackException(Exception):
 
     def __init__(self, **kwargs):
         try:
+            self.kwargs = kwargs
             self._error_string = self.message % kwargs
 
         except Exception as e:
