@@ -26,13 +26,13 @@ For some wrappers that add message versioning to rpc, see:
 """
 
 import inspect
-import logging
 
 from oslo.config import cfg
 
-from heat.openstack.common.gettextutils import _
+from heat.openstack.common.gettextutils import _  # noqa
 from heat.openstack.common import importutils
 from heat.openstack.common import local
+from heat.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
@@ -57,6 +57,7 @@ rpc_opts = [
                     'Only supported by impl_zmq.'),
     cfg.ListOpt('allowed_rpc_exception_modules',
                 default=['heat.openstack.common.exception',
+                         'heat.common.exception',
                          'nova.exception',
                          'cinder.exception',
                          'exceptions',
